matminer.distance_metrics package — matminer 0.3.1 documentation

# matminer.distance_metrics package

## Submodules

## matminer.distance_metrics.site module

THIS IS CURRENTLY JUST HOSTING LEGACY CODE.

It will soon be refactored / changed based on some discussions.

- Anubhav (12/7/17)

`matminer.distance_metrics.site.` `get_tet_bcc_motif`(structure, idx)

  Convenience class-method from Nils Zimmermann. Used to distinguish coordination environment in half-Heuslers. Args:

  > structure (pymatgen Structure): the target structure to evaluate idx (index): the site index in the structure

  Returns:
    (str) that describes site coordination enviornment
      ‘bcc’ ‘tet’ ‘unrecognized’

## matminer.distance_metrics.structure module

THIS IS CURRENTLY JUST HOSTING LEGACY CODE.

It will soon be refactored / changed based on some discussions.

- Anubhav (12/7/17)

`matminer.distance_metrics.structure.` `get_structure_distance`(s1, s2, preset_name='cn')

  Compute structure distance using an alternate (test) algorithm. Docs are minimal for now.

## Module contents